@@ -24,14 +24,11 @@
  *   MA  02111-1307 USA                                                    *
  ***************************************************************************/
 
-#include <qregexp.h>
-
 // application specific includes
 #include "smb4kauthinfo.h"
 
-#include <kmessagebox.h>
 
-Smb4KAuthInfo::Smb4KAuthInfo( const QString &wg, const QString &h, const QString &s, const QString &u, const QString &p ) : m_workgroup(wg), m_host(h), m_share(s), m_user(u), m_password(p)
+Smb4KAuthInfo::Smb4KAuthInfo( const QString &wg, const QString &h, const QString &s, const QString &u, const QString &p ) : m_workgroup(wg), m_host(h), m_share(s), m_user(u.local8Bit()), m_password(p.local8Bit())
 {
 }
 
@@ -48,13 +45,13 @@ Smb4KAuthInfo::~Smb4KAuthInfo()
 
 void Smb4KAuthInfo::setUser( const QString &user )
 {
-  m_user = user;
+  m_user = user.local8Bit();
 }
 
 
 void Smb4KAuthInfo::setPassword( const QString &passwd )
 {
-  m_password = passwd;
+  m_password = passwd.local8Bit();
 }
 
 
