@@ -343,7 +343,7 @@ void Smb4KCore::searchPrograms()
       // only modify, if the user does *not* use super or sudo.
 
       config()->setGroup( "Samba" );
-      QString filesystem = config()->readEntry( "Mount Filesystem", "smbfs" );
+      QString filesystem = config()->readEntry( "Mount Filesystem", "cifs" );
 
       config()->setGroup( "Super User Privileges" );
       bool run_suid = config()->readBoolEntry( "Run SUID", false );
@@ -426,12 +426,12 @@ void Smb4KCore::searchPrograms()
         fileList.sort();
 
         Smb4KError::error( ERROR_MISSING_PROGRAMS, fileList.join( ", " ) );
-        exit( EXIT_SUCCESS );
+        exit( EXIT_FAILURE );
       }
 #else
       fileList.sort();
       Smb4KError::error( ERROR_MISSING_PROGRAMS, fileList.join( ", " ) );
-      exit( EXIT_SUCCESS );
+      exit( EXIT_FAILURE );
 #endif
     }
   }
