@@ -34,25 +34,26 @@
 #include <qobject.h>
 #include <qmap.h>
 #include <qtimer.h>
+#include <qvaluelist.h>
 
 // application specific includes
 #include "smb4kscanner.h"
 #include "smb4kmounter.h"
-#include "smb4kpasswordhandler.h"
 #include "smb4kfileio.h"
 #include "smb4kbookmarkhandler.h"
 #include "smb4kprint.h"
 #include "smb4kshare.h"
 #include "smb4ksynchronizer.h"
-
+#include "smb4knetworkitems.h"
 
 #define smb4k_core Smb4KCore::smb4kcore()
 
 
 
 /**
- * This is the top-level core class. It inherits all other core classes
- * except the containers.
+ * This is the top-level core class. It inherits most of the core classes.
+ *
+ * @author Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
 class Smb4KCore : public QObject
@@ -106,7 +107,7 @@ class Smb4KCore : public QObject
     bool isRunning();
 
     /**
-     * Returns the current state the core class is in.
+     * Returns the current state the core is in.
      */
     int currentState() { return m_current_state; }
 
@@ -130,11 +131,6 @@ class Smb4KCore : public QObject
      */
     Smb4KFileIO *fileIO() { return m_fileIO; }
 
-    /**
-     * Returns a pointer to the password handler object.
-     */
-    Smb4KPasswordHandler *passwordHandler() { return m_password_handler; }
-
     /**
      * Returns a pointer to the printer handler object.
      */
@@ -236,11 +232,6 @@ class Smb4KCore : public QObject
      */
     Smb4KPrint *m_print;
 
-    /**
-     * The password handler pbject.
-     */
-    Smb4KPasswordHandler *m_password_handler;
-
     /**
      * The synchronizer object.
      */
@@ -288,6 +279,20 @@ class Smb4KCore : public QObject
      * A static pointer to this class.
      */
     static Smb4KCore *m_this_class;
+
+    /**
+     * This is the global list of workgroups known by Smb4K. It is filled by
+     * the scanner and may be used by all other classes that are invoked
+     * by Smb4KCore.
+     */
+    QValueList<Smb4KWorkgroupItem *> m_workgroups;
+
+    /**
+     * This is the global list of hosts known by Smb4K. It is filled by
+     * the scanner and may be used by all other classes that are invoked
+     * by Smb4KCore.
+     */
+    QValueList<Smb4KHostItem *> m_hosts;
 };
 
 #endif
