@@ -41,6 +41,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <stdlib.h>
+#include <grp.h>
 
 // application specific includes
 #include "smb4kfileio.h"
@@ -986,35 +987,84 @@ bool Smb4KFileIO::writeFile( const QString &filename, const QStringList &content
 
 bool Smb4KFileIO::createLockFile( const QString &filename )
 {
-  // Define the path of the lock file.
-  // For operating systems that do not know the /var/lock
-  // directory (like FreeBSD), we fall back to either 
-  // /var/tmp or if this also does not exist to /tmp.
+  bool ok = false;
+
+  // Determine the directory where to write the lock file. First, try
+  // /var/lock and than /var/tmp. If that does not work either, fall
+  // back to /tmp.
   if ( m_lock_file.isEmpty() )
   {
-    QDir dir( "/var/lock/" );
+    QValueList<QCString> dirs;
+    dirs << "/var/lock" << "/var/tmp" << "/tmp";
 
-    if ( dir.exists() )
-    {
-      m_lock_file = "/var/lock/smb4k.lock";
-    }
-    else
-    {
-      dir.setPath( "/var/tmp" );
+    struct stat buf;
 
-      if ( dir.exists() )
+    for ( QValueList<QCString>::ConstIterator it = dirs.begin(); it != dirs.end(); ++it )
+    {
+      // First check if /var/lock is available and writable
+      if ( lstat( *it, &buf ) == -1 )
       {
-        m_lock_file = "/var/tmp/smb4k.lock";
+        int error_number = errno;
+
+        if ( error_number != EACCES && error_number != ENOENT )
+        {
+          Smb4KError::error( ERROR_GETTING_PERMISSIONS, *it, strerror( error_number ) );
+
+          return ok; // false
+        }
       }
       else
       {
-        m_lock_file = "/tmp/smb4k.lock";
+        // Look for the groups the user is in:
+        long ngroups_max;
+        ngroups_max = sysconf(_SC_NGROUPS_MAX);
+
+        gid_t list[ngroups_max];
+
+        if ( getgroups( ngroups_max, list ) == -1 )
+        {
+          int error_number = errno;
+
+          Smb4KError::error( ERROR_GETTING_GIDS, QString::null, strerror( error_number ) );
+
+          return ok; // false
+        }
+
+        gid_t sup_gid = 65534; // set this to gid 'nobody' for initialization
+        bool found_gid = false;
+        int i = 0;
+
+        while ( list[i] )
+        {
+          if ( list[i] == buf.st_gid )
+          {
+            sup_gid = list[i];
+            found_gid = true;
+          }
+
+          i++;
+        }
+
+        // Check whether we are stat'ing a directory and that the
+        // user has read/write permissions.
+        if ( S_ISDIR( buf.st_mode ) /* is directory */ &&
+            (buf.st_uid == getuid() && (buf.st_mode & 00600) == (S_IWUSR | S_IRUSR)) /* user */ ||
+            (found_gid && buf.st_gid == sup_gid && (buf.st_mode & 00060) == (S_IWGRP | S_IRGRP)) /* group */ ||
+            ((buf.st_mode & 00006) == (S_IWOTH | S_IROTH)) /* others */ )
+        {
+          m_lock_file = *it+"/smb4k.lock";
+
+          break;
+        }
+        else
+        {
+          continue;
+        }
       }
     }
   }
 
   int file_descriptor;
-  bool ok = false;
 
   // Create the lock file if necessary and open it:
   if ( (file_descriptor = open( m_lock_file, O_RDWR|O_CREAT, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH )) == -1 )
@@ -1129,7 +1179,7 @@ bool Smb4KFileIO::createLockFile( const QString &filename )
 
 bool Smb4KFileIO::removeLockFile( const bool error_message )
 {
-  // We already have the name and location of the lock 
+  // We already have the name and location of the lock
   // file, so we do not need to define it here.
 
   int file_descriptor;
@@ -1141,7 +1191,7 @@ bool Smb4KFileIO::removeLockFile( const bool error_message )
     // Error out if the opening failed:
     int error_number = errno;
 
-    if ( error_message )
+    if ( error_message && error_number != ENOENT )
     {
       Smb4KError::error( ERROR_OPENING_FILE, m_lock_file, strerror( error_number ) );
     }
@@ -1777,8 +1827,6 @@ void Smb4KFileIO::slotReceivedStderr( KProcess *, char *buf, int len )
     emit finished();
 
     removeLockFile();
-
-    return;
   }
 }
 
