@@ -27,13 +27,15 @@
 #define SMB4KGLOBAL_H
 
 #include <qstring.h>
-#include <qmap.h>
 #include <qtimer.h>
 
 #include <kconfig.h>
 
-#include "smb4kpasswordhandler.h"
 
+// application specific includes
+#include "smb4kpasswordhandler.h"
+#include "smb4ksambaoptionshandler.h"
+#include "smb4khomesshareshandler.h"
 
 /**
  * This is the global namespace for the core classes of Smb4K.
@@ -43,38 +45,6 @@
 
 namespace Smb4KGlobal
 {
-  /**
-   * This function returns the "global" options for smbclient, i.e. if Kerberos
-   * should be used, etc.
-   *
-   * @returns           A string with the "global" options for nmblookup
-   */
-  const QString smbclientOptions();
-
-  /**
-   * This function returns the "global" options for nmblookup, i.e. the domain
-   * the client is in, if Kerberos should be used, etc.
-   *
-   * @returns           A string with the "global" options for nmblookup
-   */
-  const QString nmblookupOptions();
-
-  /**
-   * Returns the map of global smb.conf options. You can reach the value
-   * of each option by providing the lowercase option name as key, if it
-   * was defined in the global section of the smb.conf.
-   *
-   * @returns           A map of the [global] section of the smb.conf
-   */
-  const QMap<QString, QString> globalSMBOptions();
-
-  /**
-   * This function returns the WINS server the system is using.
-   *
-   * @returns           The name or IP of the WINS server
-   */
-  const QString winsServer();
-
   /**
    * This function returns the Kernel version string. Vendor specific extension
    * will be ignored. That means the string will look like this '2.6.10' rather
@@ -100,25 +70,6 @@ namespace Smb4KGlobal
    */
   int getUMASK();
 
-  /**
-   * This function returns the "global" options for the net command.
-   * You'll have to provide the command that you want to use to get the
-   * right options back.
-   *
-   * @param command     The command that should be used. It has to be one
-   *                    of the following:
-   *                    "share",
-   *                    "share_no_protocol" (same as "share" but without protocol)
-   *                    "server domain"
-   *                    "lookup host [HOST]",
-   *                    "lookup master [DOMAIN]",
-   *                    "domain".
-   *                    See also the manual page of the net command for more info.
-   *
-   * @returns           The global 'net' command options
-   */
-  const QString netOptions( const QString &command );
-
   /**
    * This is the global KConfig object for Smb4K. It points to the configuration
    * stored in $HOME/.kde/share/config/smb4krc (and *NOT* to kapp->config()).
@@ -150,22 +101,49 @@ namespace Smb4KGlobal
    *
    * @param host        The host where the homes share is located
    *
+   * @param parent      The parent widget
+   *
+   * @param name        The name of this dialog
+   *
    * @returns           A user name
    */
-  const QString specifyUser( const QString &host );
+  const QString specifyUser( const QString &host, QWidget *parent = 0, const char *name = 0 );
 
   /**
-   * This function is called if an error in one of the core classes
-   * occurred. The error codes are defined in the smb4kdefs.h file and the error
-   * message depends on the error that occurred. Mostly, it is the shell output
-   * of a process. The error codes determine the text and form of the error dialog
-   * that'll be shown.
+   * This function returns the password handler.
    *
-   * @param code        The error code
-   *
-   * @param message     The error message. May be empty.
+   * @returns           a pointer to the global password handler object.
    */
-  void showCoreError( int code, const QString &message = QString::null );
+  Smb4KPasswordHandler *passwordHandler();
+
+  /**
+   * This function returns a pointer to the global Smb4KOptionsHandler object.
+   * You need to use it if you want to retrieve (a) the custom options defined for
+   * a share, (b) the argument strings for the 'net', 'smbclient', or 'nmblookup'
+   * command, or (c) the options in the global section of the smb.conf configuration
+   * file.
+   *
+   * @returns           a pointer to the global options handler object.
+   */
+  Smb4KSambaOptionsHandler *optionsHandler();
+
+  /**
+   * This function creates a temporary directory and returns its name. If it already
+   * exists, only the name will be returned. If an failure occurrs, an error message
+   * will be shown and an empty string is returned.
+   *
+   * @returns           the name of the temporary directory.
+   */
+  const QString &tempDir();
+
+  /**
+   * Get the user names that are defined for a homes share.
+   *
+   * @param host        The name of the host where the 'homes' share is located.
+   *
+   * @returns           the list of user names for this homes share.
+   */
+  const QStringList homesUsers( const QString &host );
 };
 
 #endif
