@@ -229,7 +229,7 @@ void Smb4KMounter::abort()
     {
       KProcess p;
       p.setUseShell( true );
-      p << QString( "%1 smb4k_kill -15 %2" ).arg( suid_program ).arg( m_proc->pid() );
+      p << QString( "%1 smb4k_kill %2" ).arg( suid_program ).arg( m_proc->pid() );
       p.start( KProcess::DontCare, KProcess::NoCommunication );
     }
   }
@@ -365,6 +365,10 @@ void Smb4KMounter::import()
       m_proc_error = true;
       Smb4KError::error( ERROR_FILE_NOT_FOUND, m_proc_mounts.name() );
     }
+    else
+    {
+      // No need to do anything here
+    }
   }
   else
   {
@@ -621,7 +625,7 @@ void Smb4KMounter::mount( const QString &workgroup, const QString &host, const Q
 
   config()->setGroup( "Samba" );
 #ifndef __FreeBSD__
-  QString default_fs = config()->readEntry( "Mount Filesystem", "smbfs" );
+  QString default_fs = config()->readEntry( "Mount Filesystem", "cifs" );
   p.setFilesystem( info && !info->filesystem().isEmpty() ? info->filesystem() : default_fs );
 #else
   int default_port = config()->readNumEntry( "Port", 139 );
@@ -710,7 +714,7 @@ void Smb4KMounter::mount( const QString &workgroup, const QString &host, const Q
   delete dir;
 
   // Mount the share.
-  Smb4KAuthInfo *auth = passwordHandler()->readAuth( workgroup, host, share );
+  Smb4KAuthInfo *auth = passwordHandler()->readAuth( new Smb4KAuthInfo( workgroup, host, share ) );
 
   QString command;
 
@@ -725,8 +729,6 @@ void Smb4KMounter::mount( const QString &workgroup, const QString &host, const Q
     command = QString( "%1 smb4k_mount --suid -t %2 " ).arg( suid_program ).arg( p.filesystem() );
   }
 
-  command.append( QString( "//%1/%2 %3 " ).arg( KProcess::quote( host ) ).arg( KProcess::quote( share ) ).arg( KProcess::quote( p.path() ) ) );
-
   command.append( "-o " );
 
   if ( !workgroup.isEmpty() )
@@ -761,6 +763,8 @@ void Smb4KMounter::mount( const QString &workgroup, const QString &host, const Q
     p.setCIFSLogin( "guest" );
   }
 
+  command.append( QString( " -- //%1/%2 %3 " ).arg( KProcess::quote( host ) ).arg( KProcess::quote( share ) ).arg( KProcess::quote( p.path() ) ) );
+
   m_proc->setEnvironment( "PASSWD", !auth->password().isEmpty() ? auth->password() : "" );
 
 #else
@@ -792,11 +796,11 @@ void Smb4KMounter::mount( const QString &workgroup, const QString &host, const Q
 
   if ( !auth->user().isEmpty() )
   {
-    command.append( " //"+KProcess::quote( auth->user() )+"@"+KProcess::quote( host )+":"+port+"/"+KProcess::quote( share )+" "+KProcess::quote( p.path() ) );
+    command.append( " -- //"+KProcess::quote( auth->user() )+"@"+KProcess::quote( host )+":"+port+"/"+KProcess::quote( share )+" "+KProcess::quote( p.path() ) );
   }
   else
   {
-    command.append( " //guest@"+KProcess::quote( host )+":"+port+"/"+KProcess::quote( share )+" "+KProcess::quote( p.path() ) );
+    command.append( " -- //guest@"+KProcess::quote( host )+":"+port+"/"+KProcess::quote( share )+" "+KProcess::quote( p.path() ) );
   }
 
 #endif
@@ -895,7 +899,7 @@ void Smb4KMounter::unmount( const QString &mountpoint, bool force, bool noMessag
       {
         if ( KMessageBox::questionYesNo( 0, i18n( "Do you really want to force the unmounting of this share?" ), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "Dont Ask Forced", KMessageBox::Notify ) == KMessageBox::Yes )
         {
-          command = QString( "%1 smb4k_umount --suid --%2 -l " ).arg( suid_program ).arg( share->filesystem() );
+          command = QString( "%1 smb4k_umount --suid -t %2 -l " ).arg( suid_program ).arg( share->filesystem() );
           execute = true;
         }
         else
@@ -909,11 +913,11 @@ void Smb4KMounter::unmount( const QString &mountpoint, bool force, bool noMessag
       {
         if ( !run_suid || suid_program.isEmpty() )
         {
-          command = QString( "smb4k_umount --no-suid --%1 " ).arg( share->filesystem() );
+          command = QString( "smb4k_umount --no-suid -t %1 " ).arg( share->filesystem() );
         }
         else if ( run_suid && !suid_program.isEmpty() )
         {
-          command = QString( "%1 smb4k_umount --suid --%2 " ).arg( suid_program ).arg( share->filesystem() );
+          command = QString( "%1 smb4k_umount --suid -t %2 " ).arg( suid_program ).arg( share->filesystem() );
         }
       }
     }
@@ -925,7 +929,7 @@ void Smb4KMounter::unmount( const QString &mountpoint, bool force, bool noMessag
         {
           if ( KMessageBox::questionYesNo( 0, i18n( "Do you really want to force the unmounting of this share?" ), QString::null, KStdGuiItem::yes(), KStdGuiItem::no(), "Dont Ask Forced", KMessageBox::Notify ) == KMessageBox::Yes )
           {
-            command = QString( "%1 smb4k_umount --suid --%2 -l " ).arg( suid_program ).arg( share->filesystem() );
+            command = QString( "%1 smb4k_umount --suid -t %2 -l " ).arg( suid_program ).arg( share->filesystem() );
             execute = true;
           }
           else
@@ -939,11 +943,11 @@ void Smb4KMounter::unmount( const QString &mountpoint, bool force, bool noMessag
         {
           if ( !run_suid || suid_program.isEmpty() )
           {
-            command = QString( "smb4k_umount --no-suid --%1 " ).arg( share->filesystem() );
+            command = QString( "smb4k_umount --no-suid -t %1 " ).arg( share->filesystem() );
           }
           else if ( run_suid && !suid_program.isEmpty() )
           {
-            command = QString( "%1 smb4k_umount --suid --%2 " ).arg( suid_program ).arg( share->filesystem() );
+            command = QString( "%1 smb4k_umount --suid -t %2 " ).arg( suid_program ).arg( share->filesystem() );
           }
         }
       }
@@ -1067,7 +1071,8 @@ void Smb4KMounter::processMount()
 
   if ( m_proc->normalExit() )
   {
-    if ( m_buffer.contains( "failed", true ) == 0 &&
+    if ( m_buffer.contains( "smb4k_mount:", true ) == 0 &&
+         m_buffer.contains( "failed", true ) == 0 &&
          m_buffer.contains( "ERR", true ) == 0 &&
          m_buffer.contains( "/bin/sh:" ) == 0 &&
          m_buffer.contains( "mount:", true ) == 0 &&
@@ -1179,7 +1184,8 @@ void Smb4KMounter::processMount()
 
   if ( m_proc->normalExit() )
   {
-    if ( m_buffer.contains( "syserr =", true ) == 0 &&
+    if ( m_buffer.contains( "smb4k_mount:", true ) == 0 &&
+         m_buffer.contains( "syserr =", true ) == 0 &&
          /* To make sure we catch all errors, also check for the following
             strings. Maybe we can remove them?? */
          m_buffer.contains( "Authentication error", true ) == 0 &&
@@ -1587,13 +1593,13 @@ void Smb4KMounter::slotShutdown()
       {
         if ( run_suid )
         {
-          command.append( QString( "%1 smb4k_umount --suid --%2 " ).arg( suid_program ).arg( (*it)->filesystem() ) );
+          command.append( QString( "%1 smb4k_umount --suid -t %2 " ).arg( suid_program ).arg( (*it)->filesystem() ) );
           command.append( KProcess::quote( (*it)->path() ) );
           command.append( " ; " );
         }
         else
         {
-          command.append( QString( "smb4k_umount --no-suid --%1 " ).arg( (*it)->filesystem() ) );
+          command.append( QString( "smb4k_umount --no-suid -t %1 " ).arg( (*it)->filesystem() ) );
           command.append( KProcess::quote( (*it)->path() ) );
           command.append( " ; " );
         }
