@@ -40,15 +40,14 @@
 #include <kprocess.h>
 
 // application specific includes
-#include "smb4kpasswordhandler.h"
 #include "smb4kshare.h"
 #include "smb4kdefs.h"
-#include "smb4kdataitem.h"
 
 
 /**
  * This is a core class. It mounts the shares.
  */
+
 class Smb4KMounter : public QObject
 {
   Q_OBJECT
@@ -58,7 +57,6 @@ class Smb4KMounter : public QObject
      * The constructor.
      */
     Smb4KMounter( QObject *parent = 0, const char *name = 0 );
-
     /**
      * The destructor.
      */
@@ -73,17 +71,22 @@ class Smb4KMounter : public QObject
      * Enumeration for the state of the process. The members are also
      * used in the results() signal as return values.
      */
-    enum State{ MountRecent, Import, Mount, Unmount, UnmountAll, ForceUnmount, Idle };
+    enum State{ MountRecent, Import, Mount, Unmount, UnmountAll, Idle };
 
     /**
-     * Unmounts a share.
+     * Unmounts a share. This can either be done the "normal" way, or you may
+     * force it. If you decide the force the unmounting by setting @p force to TRUE,
+     * a lazy unmount will be initiated. With the parameter @p noMessage you can
+     * suppress any error messages.
      *
      * @param share       The share object that should be unmounted.
      *
+     * @param force       Force the unmounting of the share.
+     *
      * @param noMessage   Determines whether this function should emit an error code in case of an error.
      *                    The default value is FALSE.
      */
-    void unmountShare( Smb4KShare *share, bool noMessage = false );
+    void unmountShare( Smb4KShare *share, bool force = false, bool noMessage = false );
 
     /**
      * Unmounts all shares at once.
@@ -92,14 +95,17 @@ class Smb4KMounter : public QObject
 
     /**
      * Mounts a share.
+     *
+     * @param workgroup   The workgroup of the share.
+     *
+     * @param host        The server where the share is located.
+     *
+     * @param ip          The IP address of the host.
+     *
+     * @param share       The name of the share.
      */
     void mountShare( const QString &workgroup, const QString &host, const QString &ip, const QString &share );
 
-    /**
-     * Unmounts a dead share using super/sudo and 'umount -l' command.
-     */
-    void forceUnmountShare( Smb4KShare *share );
-
     /**
      * Returns the unsorted list of mounted shares.
      */
@@ -138,6 +144,14 @@ class Smb4KMounter : public QObject
      */
     const QValueList<Smb4KShare *> getBrokenShares();
 
+    /**
+     * This function executes Smb4KMounter::slotShutdown(). Under normal circumstances,
+     * there is no need to use this function, because everything that is done here is
+     * also done when KApplication::shutDown() is emitted. However, it comes in handy
+     * when you need to perform last actions in a plugin.
+     */
+    void prepareForShutdown();
+
   signals:
     /**
      * This signal emits the run state.
@@ -196,12 +210,12 @@ class Smb4KMounter : public QObject
     void slotProcessExited( KProcess * );
 
     /**
-     * Is called, if output is received at Stdout.
+     * Is called, if output is received on Stdout.
      */
     void slotReceivedStdout( KProcess *, char *buf, int len );
 
     /**
-     * Is called, if output is received a Stderr.
+     * Is called, if output is received on Stderr.
      */
     void slotReceivedStderr( KProcess *, char *buf, int len );
 
@@ -236,25 +250,13 @@ class Smb4KMounter : public QObject
     /**
      * Unmounts the selected item.
      */
-    void unmount( const QString &mountpoint, bool noMessage );
-
-    /**
-     * Unmounts dead shares.
-     */
-    void forceUnmount( const QString &mountpoint );
+    void unmount( const QString &mountpoint, bool noMessage, bool force = false );
 
     /**
      * Unmounts all shares at once.
      */
     void unmountAll();
 
-    /**
-     * This function returns the advanced option string that is needed to
-     * mount the shares. The contents is determined by the choice of the
-     * user (config dialog).
-     */
-    const QString getMountOptions();
-
     /**
      * The KProcess object.
      */
@@ -286,11 +288,6 @@ class Smb4KMounter : public QObject
      */
     bool m_proc_error;
 
-    /**
-     * This is the password handler for this class.
-     */
-    Smb4KPasswordHandler *m_password_handler;
-
     /**
      * The internal state of the process. Do not mix this up with
      * the state that's emitted to notify the application about changes.
