@@ -161,7 +161,7 @@ void Smb4KPasswordHandler::open_close_wallet()
 
 bool Smb4KPasswordHandler::askpass( const QString &workgroup, const QString &host, const QString &share, int desc, QWidget *parent, const char *name )
 {
-  m_auth = readAuth( workgroup, host, share );
+  m_auth = readAuth( new Smb4KAuthInfo( workgroup, host, share ) );
 
   // Set up the askpass dialog:
 
@@ -328,69 +328,73 @@ bool Smb4KPasswordHandler::askpass( const QString &workgroup, const QString &hos
 }
 
 
-Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( const QString &workgroup, const QString &host, const QString &share )
+Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( Smb4KAuthInfo *authInfo )
 {
+  if ( !authInfo )
+  {
+    return authInfo;
+  }
+
   open_close_wallet();
 
   m_config->setGroup( "Authentication" );
   bool use_default = m_config->readBoolEntry( "Default Authentication" );
 
-  Smb4KAuthInfo *auth = new Smb4KAuthInfo( workgroup, host, share );
-
   if ( m_wallet && m_wallet->isOpen() )
   {
     QStringList full_list = m_wallet->entryList();
-    QStringList host_list = full_list.grep( host, false );
+    QStringList host_list = full_list.grep( authInfo->host(), false );
 
     if ( !host_list.isEmpty() )
     {
       for ( QStringList::ConstIterator it = host_list.begin(); it != host_list.end(); ++it )
       {
-         if ( !share.isEmpty() && (*it).upper().contains( ":"+host.upper()+":"+share.upper() ) != 0 )
+         if ( !authInfo->share().isEmpty() &&
+              (*it).upper().contains( ":"+authInfo->host().upper()+":"+authInfo->share().upper() ) != 0 )
         {
           QString user = (*it).section( ":", 3, 3 ).stripWhiteSpace();
           QString pass;
 
           m_wallet->readPassword( *it, pass );
 
-          auth->setUser( user );
-          auth->setPassword( pass );
+          authInfo->setUser( user );
+          authInfo->setPassword( pass );
 
           break;
         }
-        else if ( !share.isEmpty() && (*it).upper().contains( ":"+host.upper()+":*" ) != 0 )
+        else if ( !authInfo->share().isEmpty() && (*it).upper().contains( ":"+authInfo->host().upper()+":*" ) != 0 )
         {
           QString user = (*it).section( ":", 3, 3 ).stripWhiteSpace();
           QString pass;
 
           m_wallet->readPassword( *it, pass );
 
-          auth->setUser( user );
-          auth->setPassword( pass );
+          authInfo->setUser( user );
+          authInfo->setPassword( pass );
 
           continue;
         }
-        else if ( share.isEmpty() && (*it).upper().contains( ":"+host.upper()+":" ) )
+        else if ( authInfo->share().isEmpty() && (*it).upper().contains( ":"+authInfo->host().upper()+":" ) )
         {
           QString user = (*it).section( ":", 3, 3 ).stripWhiteSpace();
           QString pass;
 
           m_wallet->readPassword( *it, pass );
 
-          auth->setUser( user );
-          auth->setPassword( pass );
+          authInfo->setUser( user );
+          authInfo->setPassword( pass );
 
           break;
         }
-        else if ( share.isEmpty() && (*it).upper().startsWith( "DEFAULT:" ) && use_default )
+        else if ( authInfo->share().isEmpty() && (*it).upper().startsWith( "DEFAULT:" ) && use_default )
         {
           QString user = (*it).section( ":", 1, 1 ).stripWhiteSpace();
           QString pass;
 
           m_wallet->readPassword( *it, pass );
 
-          auth->setUser( user );
-          auth->setPassword( pass );
+          authInfo->setUser( user );
+          authInfo->setPassword( pass );
 
           continue;
         }
@@ -416,8 +420,8 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( const QString &workgroup, const Q
             user = (*it).section( ":", 1, 1 ).stripWhiteSpace();
             m_wallet->readPassword( *it, pass );
 
-            auth->setUser( user );
-            auth->setPassword( pass );
+            authInfo->setUser( user );
+            authInfo->setPassword( pass );
 
             break;
           }
@@ -438,27 +442,27 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( const QString &workgroup, const Q
     {
       for ( QValueList<Smb4KAuthInfo *>::Iterator it = m_auth_list.begin(); it != m_auth_list.end(); ++it )
       {
-        if ( (QString::compare( (*it)->workgroup().upper(), workgroup.upper() ) == 0 &&
-              QString::compare( (*it)->host().upper(), host.upper() ) == 0 &&
-              QString::compare( (*it)->share().upper(), share.upper() ) == 0) ||
+        if ( (QString::compare( (*it)->workgroup().upper(), authInfo->workgroup().upper() ) == 0 &&
+              QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
+              QString::compare( (*it)->share().upper(), authInfo->share().upper() ) == 0) ||
              (QString::compare( (*it)->workgroup().upper(), "*" ) == 0 &&
-              QString::compare( (*it)->host().upper(), host.upper() ) == 0 &&
-              QString::compare( (*it)->share().upper(), share.upper() ) == 0) )
+              QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
+              QString::compare( (*it)->share().upper(), authInfo->share().upper() ) == 0) )
         {
-          auth->setUser( (*it)->user() );
-          auth->setPassword( (*it)->password() );
+          authInfo->setUser( (*it)->user() );
+          authInfo->setPassword( (*it)->password() );
 
           break;
         }
-        else if ( (QString::compare( (*it)->workgroup().upper(), workgroup.upper() ) == 0 &&
-                   QString::compare( (*it)->host().upper(), host.upper() ) == 0 &&
+        else if ( (QString::compare( (*it)->workgroup().upper(), authInfo->workgroup().upper() ) == 0 &&
+                   QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
                    QString::compare( (*it)->share().upper(), "*" ) == 0) ||
                   (QString::compare( (*it)->workgroup().upper(), "*" ) == 0 &&
-                   QString::compare( (*it)->host().upper(), host.upper() ) == 0 &&
+                   QString::compare( (*it)->host().upper(), authInfo->host().upper() ) == 0 &&
                    QString::compare( (*it)->share().upper(), "*" ) == 0) )
         {
-          auth->setUser( (*it)->user() );
-          auth->setPassword( (*it)->password() );
+          authInfo->setUser( (*it)->user() );
+          authInfo->setPassword( (*it)->password() );
 
           continue;
         }
@@ -472,8 +476,8 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( const QString &workgroup, const Q
     {
       if ( m_temp_auth )
       {
-        auth->setUser( m_temp_auth->user() );
-        auth->setPassword( m_temp_auth->password() );
+        authInfo->setUser( m_temp_auth->user() );
+        authInfo->setPassword( m_temp_auth->password() );
 
         delete m_temp_auth;
         m_temp_auth = NULL;
@@ -487,7 +491,7 @@ Smb4KAuthInfo *Smb4KPasswordHandler::readAuth( const QString &workgroup, const Q
 
 #endif
 
-  return auth;
+  return authInfo;
 }
 
 
@@ -747,7 +751,7 @@ void Smb4KPasswordHandler::slotGetPassword( const QString &username )
 {
   if ( m_dlg && m_auth )
   {
-    Smb4KAuthInfo *auth = readAuth( m_auth->workgroup().upper(), m_auth->host().upper(), username );
+    Smb4KAuthInfo *auth = readAuth( new Smb4KAuthInfo( m_auth->workgroup().upper(), m_auth->host().upper(), username ) );
     ((KLineEdit *)m_dlg->child( "AskPassPasswordEdit", "KLineEdit", true ))->setText( auth->password() );
     delete auth;
 
