@@ -110,10 +110,6 @@ bool Smb4KPrint::print( Smb4KPrintInfo *info )
 
     KFileItem file_item = KFileItem( KFileItem::Unknown, KFileItem::Unknown, url, false );
 
-    kdDebug() << file_item.mimetype() << endl;
-
-    return true;
-
     if ( QString::compare( file_item.mimetype(), "application/postscript" ) == 0 ||
          QString::compare( file_item.mimetype(), "application/pdf" ) == 0 ||
          file_item.mimetype().startsWith( "image" ) )
@@ -168,7 +164,7 @@ bool Smb4KPrint::print( Smb4KPrintInfo *info )
 
 void Smb4KPrint::setDeviceURI()
 {
-  Smb4KAuthInfo *auth = passwordHandler()->readAuth( m_info->workgroup(), m_info->host(), m_info->printer() );
+  Smb4KAuthInfo *auth = passwordHandler()->readAuth( new Smb4KAuthInfo( m_info->workgroup(), m_info->host(), m_info->printer() ) );
 
   QString uri;
 
