@@ -224,7 +224,7 @@ void Smb4KSambaOptionsHandler::write_options()
   QString default_uid = m_config->readEntry( "Mount UID", QString::null ); // config dlg: i18n( "default" )
   QString default_gid = m_config->readEntry( "Mount GID", QString::null ); // config dlg: i18n( "default" )
 #ifndef __FreeBSD__
-  QString default_filesystem = m_config->readEntry( "Mount Filesystem", "smbfs" );
+  QString default_filesystem = m_config->readEntry( "Mount Filesystem", "cifs" );
   bool default_readwrite = m_config->readBoolEntry( "Mount ReadWrite", true );
 #endif
 
@@ -514,7 +514,7 @@ const QString Smb4KSambaOptionsHandler::netOptions( int command, const QString &
     }
     case ServerDomain:
     {
-      args.append( " rap server domain" );
+      args.append( " rap server" );
 
       // No network item is needed here.
 
@@ -602,7 +602,7 @@ const QString Smb4KSambaOptionsHandler::mountOptions( const QString &share )
 
   QString filesystem = info && !info->filesystem().isEmpty() ?
                        info->filesystem() :
-                       m_config->readEntry( "Mount Filesystem", "smbfs" );
+                       m_config->readEntry( "Mount Filesystem", "cifs" );
   bool kerberos = info ?
                   info->kerberos() :
                   m_config->readBoolEntry( "Use Kerberos", false );
