@@ -115,8 +115,6 @@ Smb4KBookmarkEditor::~Smb4KBookmarkEditor()
 
 void Smb4KBookmarkEditor::slotRightButtonPressed( QListViewItem *item, const QPoint &pos, int )
 {
-  KActionMenu *menu = new KActionMenu( this, "BookmarkEditorPopupMenu" );
-
   if ( !item )
   {
     m_collection->action( "remove_bookmark" )->setEnabled( false );
@@ -135,8 +133,14 @@ void Smb4KBookmarkEditor::slotRightButtonPressed( QListViewItem *item, const QPo
     m_collection->action( "remove_all_bookmarks" )->setEnabled( true );
   }
 
-  menu->insert( m_collection->action( "remove_bookmark" ) );
-  menu->insert( m_collection->action( "remove_all_bookmarks" ) );
+  KActionMenu *menu = static_cast<KActionMenu *>( child( "BookmarkEditorPopupMenu", "KActionMenu", true ) );
+
+  if ( !menu )
+  {
+    menu = new KActionMenu( this, "BookmarkEditorPopupMenu" );
+    menu->insert( m_collection->action( "remove_bookmark" ) );
+    menu->insert( m_collection->action( "remove_all_bookmarks" ) );
+  }
 
   menu->popup( pos );
 }
