@@ -33,8 +33,8 @@
 // KDE includes
 #include <kpopupmenu.h>
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <kdebug.h>
+#include <kapplication.h>
 
 // application specific includes
 #include "smb4kbookmarkmenuwidget.h"
@@ -216,8 +216,8 @@ void Smb4KBookmarkMenuWidget::slotUpdatedShareList()
         {
           if ( QString::compare( (*it)->plainText().upper(), (*i)->name().upper() ) == 0 &&
                (((int)getuid() == (*i)->uid() && (int)getgid() == (*i)->gid()) ||
-               (*i)->canonicalPath().startsWith( QDir::home().canonicalPath() ) ||
-               (*i)->canonicalPath().startsWith( QDir( mount_prefix ).canonicalPath() )) )
+               qstrncmp( (*i)->canonicalPath(), QDir::home().canonicalPath(), QDir::home().canonicalPath().length() ) == 0 ||
+               qstrncmp( (*i)->canonicalPath(), QDir( mount_prefix ).canonicalPath(), QDir( mount_prefix ).canonicalPath().length() ) == 0) )
           {
             enable = false;
             break;
@@ -235,7 +235,7 @@ void Smb4KBookmarkMenuWidget::slotActivated()
 {
   if ( m_action && m_action->plainText().stripWhiteSpace().startsWith( "//" ) )
   {
-    Smb4KBookmark *bookmark = smb4k_core->bookmarkHandler()->getBookmark( m_action->plainText() );
+    Smb4KBookmark *bookmark = smb4k_core->bookmarkHandler()->findBookmark( m_action->plainText() );
 
     if ( bookmark )
     {
@@ -253,11 +253,10 @@ void Smb4KBookmarkMenuWidget::slotBookmarksUpdated()
 
 void Smb4KBookmarkMenuWidget::slotEditBookmarks()
 {
-  if ( child( "BookmarkEditor", "KDialogBase", true ) == 0 )
-  {
-    Smb4KBookmarkEditor *editor = new Smb4KBookmarkEditor( 0, "BookmarkEditor" );
-    editor->show();
-  }
+  Smb4KBookmarkEditor *editor = new Smb4KBookmarkEditor( kapp->mainWidget() && kapp->mainWidget()->isShown() ?
+                                                         kapp->mainWidget() : 0,
+                                                         "BookmarkEditor" );
+  editor->exec();
 }
 
 
