@@ -35,34 +35,23 @@
 #include "smb4kbrowserwidgetitem.h"
 
 Smb4KBrowserWidgetItem::Smb4KBrowserWidgetItem( QListView *parent, Smb4KWorkgroupItem *item )
-: QListViewItem( parent, item->workgroup() ), m_workgroup( *item ), m_mounted( false ), m_type( Smb4KBrowserWidgetItem::Workgroup )
+: KListViewItem( parent, item->workgroup() ), m_workgroup( *item ), m_mounted( false ), m_type( Smb4KBrowserWidgetItem::Workgroup )
 {
-  m_desktop_icon = DesktopIcon( "network_local" );
-  setPixmap( 0, SmallIcon( "network_local" ) );
+  setIcon();
 }
 
 
 Smb4KBrowserWidgetItem::Smb4KBrowserWidgetItem( QListViewItem *parent, Smb4KHostItem *item )
-: QListViewItem( parent, item->name(), QString::null, item->ip(), item->comment() ), m_host( *item ), m_mounted( false ), m_type( Smb4KBrowserWidgetItem::Host )
+: KListViewItem( parent, item->name(), QString::null, item->ip(), item->comment() ), m_host( *item ), m_mounted( false ), m_type( Smb4KBrowserWidgetItem::Host )
 {
-  m_desktop_icon = DesktopIcon( "server" );
-  setPixmap( 0, SmallIcon( "server" ) );
+  setIcon();
 }
 
 
 Smb4KBrowserWidgetItem::Smb4KBrowserWidgetItem( QListViewItem *parent, Smb4KShareItem *item )
-: QListViewItem( parent, item->name(), item->plainType(), QString::null, item->comment() ), m_share( *item ), m_mounted( false ), m_type( Smb4KBrowserWidgetItem::Share )
+: KListViewItem( parent, item->name(), item->plainType(), QString::null, item->comment() ), m_share( *item ), m_mounted( false ), m_type( Smb4KBrowserWidgetItem::Share )
 {
-  if ( item->plainType().contains( "Printer" ) )
-  {
-    m_desktop_icon = DesktopIcon( "printer1" );
-    setPixmap( 0, SmallIcon( "printer1" ) );
-  }
-  else
-  {
-    m_desktop_icon = DesktopIcon( "folder" );
-    setPixmap( 0, SmallIcon( "folder" ) );
-  }
+  setIcon();
 }
 
 
@@ -71,22 +60,59 @@ Smb4KBrowserWidgetItem::~Smb4KBrowserWidgetItem()
 }
 
 
+void Smb4KBrowserWidgetItem::setIcon()
+{
+  switch ( m_type )
+  {
+    case Workgroup:
+    {
+      m_desktop_icon = DesktopIcon( "network_local" );
+      setPixmap( 0, SmallIcon( "network_local" ) );
+      break;
+    }
+    case Host:
+    {
+      m_desktop_icon = DesktopIcon( "server" );
+      setPixmap( 0, SmallIcon( "server" ) );
+      break;
+    }
+    case Share:
+    {
+      if ( QString::compare( m_share.plainType(), "Printer" ) == 0 )
+      {
+        m_desktop_icon = DesktopIcon( "printer1" );
+        setPixmap( 0, SmallIcon( "printer1" ) );
+      }
+      else
+      {
+        if ( m_mounted )
+        {
+          m_desktop_icon = DesktopIcon( "folder_open" );
+          setPixmap( 0, SmallIcon( "folder_open" ) );
+        }
+        else
+        {
+          m_desktop_icon = DesktopIcon( "folder" );
+          setPixmap( 0, SmallIcon( "folder" ) );
+        }
+      }
+      break;
+    }
+    default:
+    {
+      break;
+    }
+  }
+}
+
+
 void Smb4KBrowserWidgetItem::setMounted( bool mounted )
 {
   if ( m_type == Share && QString::compare( m_share.plainType(), "Disk" ) == 0 )
   {
     m_mounted = mounted;
 
-    if ( mounted )
-    {
-      m_desktop_icon = DesktopIcon( "folder_open" );
-      setPixmap( 0, SmallIcon( "folder_open" ) );
-    }
-    else
-    {
-      m_desktop_icon = DesktopIcon( "folder" );
-      setPixmap( 0, SmallIcon( "folder" ) );
-    }
+    setIcon();
   }
 }
 
