@@ -320,7 +320,7 @@ void Smb4KCustomOptionsDialog::setupDialog()
 #ifndef __FreeBSD__
       default_kerberos = config()->readBoolEntry( "Use Kerberos", false );
       default_readwrite = config()->readBoolEntry( "Mount ReadWrite", true );
-      default_filesystem = config()->readEntry( "Mount Filesystem", "smbfs" );
+      default_filesystem = config()->readEntry( "Mount Filesystem", "cifs" );
 #endif
 
       // Define the values that have to be put into the widgets:
