@@ -39,10 +39,11 @@
 #include "smb4kshareoptions.h"
 #include "smb4knetworkoptions.h"
 #include "smb4kauthoptions.h"
-#include "smb4kappearanceoptions.h"
+// #include "smb4kappearanceoptions.h"
 #include "smb4ksambaoptions.h"
 #include "smb4ksuperuseroptions.h"
 #include "smb4krsyncoptions.h"
+#include "smb4kuserinterfaceoptions.h"
 
 
 class Smb4KOptionsDlg : public KDialogBase
@@ -56,6 +57,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * The constructor
      */
     Smb4KOptionsDlg( QWidget *parent = 0, const char *name = 0, bool modal = false );
+
     /**
      * The destructor
      */
@@ -74,6 +76,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * Saves the options.
      */
     bool saveOptions();
+
     /**
      * Reads the options.
      */
@@ -84,20 +87,24 @@ class Smb4KOptionsDlg : public KDialogBase
      * Is called when the OK button has been pressed.
      */
     void slotOk();
+
     /**
      * Is called when the Apply button has been pressed.
      */
     void slotApply();
+
     /**
      * This slot is called when the SUID entries were written to the files.
      */
-    void slotFinishedSUIDWriting();
+    void slotFinishedWriting();
+
     /**
      * This slot is connected to the Smb4KFileIO::error_suid_writing()
      * signal and re-establishes the previous state, if the writing to
      * /etc/super.tab or /etc/sudoers was canceled().
      */
-    void slotSUIDWritingFailed();
+    void slotWritingFailed();
+
     /**
      * This slot is invoked, if the user clicked the "Remove Entries"
      * button in the "Super User" tab. It initiates the removal of the
@@ -110,6 +117,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * Set up the browse options page.
      */
     void setupNetworkOptions();
+
     /**
      * The browse option page object
      */
@@ -119,6 +127,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * Set up the mount options page.
      */
     void setupShareOptions();
+
     /**
      * The mount options page object
      */
@@ -128,6 +137,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * Set up the authentication page.
      */
     void setupAuthOptions();
+
     /**
      * The authentication page object
      */
@@ -136,16 +146,18 @@ class Smb4KOptionsDlg : public KDialogBase
     /**
      * Set up the appearance page.
      */
-    void setupAppearanceOptions();
+    void setupUserInterfaceOptions();
+
     /**
      * The appearance page object
      */
-    Smb4KAppearanceOptions *m_appearancePage;
+    Smb4KUserInterfaceOptions *m_uiPage;
 
     /**
      * Sets up the Samba options page.
      */
     void setupSambaOptions();
+
     /**
      * The Samba page object
      */
@@ -155,6 +167,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * Sets up the super user options page.
      */
     void setupSuperUserOptions();
+
     /**
      * The super user options page object
      */
@@ -164,6 +177,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * Sets up the synchronize options page
      */
     void setupRsyncOptions();
+
     /**
      * The synchronize options page object
      */
@@ -174,14 +188,16 @@ class Smb4KOptionsDlg : public KDialogBase
      * have been provided before applying any changes.
      */
     bool check();
+
     /**
      * Tells which button has been clicked.
      */
     QString m_button;
+
     /**
      * The enumeration for the pages.
      */
-    enum Pages{ Appearance = 0, Network = 1, Shares = 2, Authentication = 3, Samba = 4, SuperUser = 5, Rsync };
+    enum Pages{ UserInterface = 0, Network = 1, Shares = 2, Authentication = 3, Samba = 4, SuperUser = 5, Rsync = 6 };
 };
 
 #endif
