@@ -118,7 +118,7 @@ class Smb4KPreviewDialog : public KDialogBase
     /**
      * Enumeration for the buttons.
      */
-    enum ButtonID{ Reload, Up, Back, Forward, Combo };
+    enum ButtonID{ Reload, Up, Back, Forward, Combo, None };
 
     /**
      * Set the tooltips.
@@ -192,9 +192,8 @@ class Smb4KPreviewDialog : public KDialogBase
     QStringList::Iterator m_current_item;
 
     /**
-     * This boolean is true if we are moving through the
-     * history and false if we are not (anymore).
+     * The current button id
      */
-    bool m_move_through;
+    int m_button_id;
 };
 #endif
