@@ -34,6 +34,7 @@
 #include <kiconeffect.h>
 #include <kmessagebox.h>
 #include <kapplication.h>
+#include <kdebug.h>
 
 // application specific includes
 #include "smb4ksearchdialog.h"
@@ -64,7 +65,6 @@ Smb4KSearchDialog::Smb4KSearchDialog( QWidget *parent, const char *name ) : QWid
   grid->addWidget( m_toolbar, 0, 0, 0 );
   grid->addWidget( m_window, 1, 0, 0 );
 
-
   // Internal connections
   connect( m_toolbar, SIGNAL( clicked( int ) ),
            this,      SLOT( slotButtonClicked( int ) ) );
@@ -82,6 +82,8 @@ Smb4KSearchDialog::Smb4KSearchDialog( QWidget *parent, const char *name ) : QWid
            this,                  SLOT( slotReceivedSearchResult( Smb4KHostItem * ) ) );
   connect( smb4k_core->scanner(), SIGNAL( hostListChanged() ),
            this,                  SLOT( slotCheckItemInBrowser() ) );
+  connect( kapp,                  SIGNAL( iconChanged( int ) ),
+           this,                  SLOT( slotIconChanged( int ) ) );
 
   QToolTip::add( m_window, i18n( "Search results" ) );
   QToolTip::add( m_input, i18n( "Enter host here" ) );
@@ -93,6 +95,48 @@ Smb4KSearchDialog::~Smb4KSearchDialog()
 }
 
 
+void Smb4KSearchDialog::changeIcons()
+{
+  uint index = 0;
+
+  while ( index < m_window->count() )
+  {
+    if ( (m_window->text( index ).contains( "(" ) != 0 &&
+         m_window->text( index ).contains( ")" ) != 0) ||
+         (m_window->text( index ).contains( "[" ) != 0 &&
+         m_window->text( index ).contains( "]" ) != 0) )
+    {
+      Smb4KHostItem *host = smb4k_core->scanner()->getHost(
+                            m_window->text( index ).section( " ", 0, 0 ).stripWhiteSpace(),
+                            m_window->text( index ).section( "[", 1, 1 ).section( "]", 0, 0 ) );
+
+      if ( host )
+      {
+        KIconEffect e;
+        QImage over = SmallIcon( "button_ok" ).convertToImage();
+        QImage src = SmallIcon( "server" ).convertToImage();
+        e.semiTransparent( over );
+        e.overlay( src, over );
+
+        QPixmap pix( src );
+
+        m_window->changeItem( pix, m_window->text( index ), index );
+      }
+      else
+      {
+        m_window->changeItem( SmallIcon( "server" ), m_window->text( index ), index );
+      }
+    }
+    else
+    {
+      m_window->changeItem( SmallIcon( "no" ), m_window->text( index ), index );
+    }
+
+    index++;
+  }
+}
+
+
 /////////////////////////////////////////////////////////////////////////////
 // SLOT IMPLEMENTATIONS
 /////////////////////////////////////////////////////////////////////////////
@@ -175,7 +219,7 @@ void Smb4KSearchDialog::slotItemDoubleClicked( QListBoxItem *item )
 {
   if ( item )
   {
-    if ( !item->text().isEmpty() &&
+    if ( !item->text().isEmpty() && /* We need the workgroup: */
          item->text().contains( "[" ) != 0 &&
          item->text().contains( "]" ) != 0 )
     {
@@ -192,67 +236,15 @@ void Smb4KSearchDialog::slotItemDoubleClicked( QListBoxItem *item )
 }
 
 
-// This slot is more or less superfluous, because all marking of the
-// items will also be done by slotCheckItemInBrowser(), except if someone
-// messes up Smb4KBrowserWidget::insertItem(). Nevertheless, we'll keep this
-// function.
-void Smb4KSearchDialog::slotItemAddedToBrowser( Smb4KHostItem *item )
+void Smb4KSearchDialog::slotCheckItemInBrowser()
 {
-  QListBoxItem *host = m_window->findItem( item->name(), BeginsWith );
-
-  if ( host )
-  {
-    KIconEffect e;
-    QImage over = SmallIcon( "button_ok" ).convertToImage();
-    QImage src = SmallIcon( "server" ).convertToImage();
-    e.semiTransparent( over );
-    e.overlay( src, over );
-
-    QPixmap pix( src );
-
-    m_window->changeItem( pix, host->text(), m_window->index( host ) );
-  }
+  changeIcons();
 }
 
 
-void Smb4KSearchDialog::slotCheckItemInBrowser()
+void Smb4KSearchDialog::slotIconChanged( int )
 {
-  if ( m_window->count() != 0 )
-  {
-    uint index = 0;
-
-    while ( index < m_window->count() )
-    {
-      if ( (m_window->text( index ).contains( "(" ) != 0 &&
-         m_window->text( index ).contains( ")" ) != 0) ||
-         (m_window->text( index ).contains( "[" ) != 0 &&
-         m_window->text( index ).contains( "]" ) != 0) )
-      {
-        Smb4KHostItem *host = smb4k_core->scanner()->getHost(
-                                   m_window->text( index ).section( " ", 0, 0 ).stripWhiteSpace(),
-                                   m_window->text( index ).section( "[", 1, 1 ).section( "]", 0, 0 ) );
-
-        if ( host )
-        {
-          KIconEffect e;
-          QImage over = SmallIcon( "button_ok" ).convertToImage();
-          QImage src = SmallIcon( "server" ).convertToImage();
-          e.semiTransparent( over );
-          e.overlay( src, over );
-
-          QPixmap pix( src );
-
-          m_window->changeItem( pix, m_window->text( index ), index );
-        }
-        else
-        {
-          m_window->changeItem( SmallIcon( "server" ), m_window->text( index ), index );
-        }
-      }
-
-      index++;
-    }
-  }
+  changeIcons();
 }
 
 #include "smb4ksearchdialog.moc"
