@@ -33,6 +33,7 @@
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
+#include <kapplication.h>
 
 // application specific includes
 #include "smb4ksharesmenuwidget.h"
@@ -96,7 +97,7 @@ Smb4KSharesMenuWidget::~Smb4KSharesMenuWidget()
 
 void Smb4KSharesMenuWidget::slotUpdatedShareList()
 {
-  config()->setGroup( "Appearance" );
+  config()->setGroup( "User Interface" );
   bool show_foreign = config()->readBoolEntry( "Show All Shares", false );
   bool show_mountpoint = config()->readBoolEntry( "Show Mount Point", false );
 
@@ -262,8 +263,10 @@ void Smb4KSharesMenuWidget::slotUpdatedShareList()
           menu->unmountAction()->setName( "[unmount]_"+(*it)->path() );
           connect( menu->unmountAction(), SIGNAL( activated() ), this, SLOT( slotUnmount() ) );
 
+#ifdef __linux__
           menu->forcedUnmountAction()->setName( "[force]_"+(*it)->path() );
           connect( menu->forcedUnmountAction(), SIGNAL( activated() ), this, SLOT( slotForceUnmount() ) );
+#endif
 
           menu->filemanagerAction()->setName( "[filemanager]_"+(*it)->path() );
           menu->filemanagerAction()->setEnabled( !(*it)->isBroken() );
@@ -325,7 +328,7 @@ void Smb4KSharesMenuWidget::slotUnmount()
 
   if ( share )
   {
-    smb4k_core->mounter()->unmountShare( share );
+    smb4k_core->mounter()->unmountShare( share, false, false );
   }
 }
 
@@ -338,7 +341,9 @@ void Smb4KSharesMenuWidget::slotSynchronize()
 
   if ( share )
   {
-    smb4k_core->synchronizer()->synchronize( share );
+    smb4k_core->synchronizer()->synchronize( share,
+                                             kapp->mainWidget() && kapp->mainWidget()->isShown() ?
+                                             kapp->mainWidget() : 0 );
   }
 }
 
@@ -351,7 +356,7 @@ void Smb4KSharesMenuWidget::slotForceUnmount()
 
   if ( share )
   {
-    smb4k_core->mounter()->forceUnmountShare( share );
+    smb4k_core->mounter()->unmountShare( share, true, false );
   }
 }
 
